@@ -14,19 +14,18 @@
 """Backwards compatibility: moved this module to
 `zope.traversing.publicationtraverse`.
 
-$Id: publicationtraverse.py 100294 2009-05-23 21:06:18Z shane $
+$Id: publicationtraverse.py 100362 2009-05-25 16:40:17Z shane $
 """
 __docformat__ = 'restructuredtext'
 
-from zope.deprecation import moved
-moved('zope.traversing.publicationtraverse')
-
-# AFAICT, no one depends on the exception types defined below,
-# nor should they!  - 2009-05-23
+from zope.traversing.publicationtraverse import PublicationTraverse #BBB import
+from zope.traversing.publicationtraverse import PublicationTraverser #BBB import
 
+#BBB: do not use
 class DuplicateNamespaces(Exception):
     """More than one namespace was specified in a request"""
 
+#BBB: do not use
 class UnknownNamespace(Exception):
     """A parameter specified an unknown namespace"""
 
